import { mapShortCellId } from './utils/mapShortCellId';
export class Corner {
    sourceCell;
    directionFromSourceCell;
    neighborCells;
    id;
    /**
     * All cells, that are connected to this corner
     */
    adjacentCells;
    /**
     * @param sourceCell
     * @param directionFromSourceCell
     * @param neighborCells All cells, that are connected to the sourceCell through this corner
     */
    constructor(sourceCell, directionFromSourceCell, neighborCells) {
        this.sourceCell = sourceCell;
        this.directionFromSourceCell = directionFromSourceCell;
        this.neighborCells = neighborCells;
        this.adjacentCells = [this.sourceCell, ...this.neighborCells];
        const neighborCellIds = this.neighborCells
            .map((adjacentCell) => mapShortCellId(adjacentCell))
            .filter(Boolean);
        const cellIds = neighborCellIds.length > 0
            ? [mapShortCellId(sourceCell), ...neighborCellIds].toSorted().join('|')
            : [mapShortCellId(sourceCell), directionFromSourceCell].join('|');
        this.id = `corner[${cellIds}]`;
    }
}
