import type { Grid } from './Grid';
import type { Cell } from './Cell';
import { type CellValueChangedEvent } from './utils';
import type { Directions } from './Directions';
/**
 * The column of a grid contains all information of the columns' cells
 */
export declare class Column<TValue, TDirections extends Directions, TCell extends Cell<TValue, TDirections>> {
    private grid;
    col: number;
    readonly id: string;
    private readonly _cells;
    private readonly eventDispatcher;
    /**
     * @param grid The grid this column is part of
     * @param col The column coordinate inside the grid
     */
    constructor(grid: Grid<TValue, TDirections, TCell>, col: number);
    /**
     * @returns all cells of this column
     */
    get cells(): TCell[];
    /**
     * @param row The row coordinate of the grid
     * @returns A cell
     */
    getCell(row: number): TCell;
    /**
     * @param callback A function that should be called, when a cell value of this column changes
     * @returns a function to unregister the callback
     */
    onCellValueChanged(callback: (event: CellValueChangedEvent<TValue, TDirections>) => void): () => void;
}
//# sourceMappingURL=Column.d.ts.map